.. rst-class:: detail

ReadAnalog
=====================

.. currentmodule:: compas_rrc

.. autoclass:: ReadAnalog

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~ReadAnalog.__init__
        ~ReadAnalog.from_msg
        ~ReadAnalog.parse_feedback
    
    